@@ -2,8 +2,7 @@
 # -*- coding: utf-8 -*-
 
 ###################
-#    This package implements a web server to run scripts or executables
-#    from the command line and display the result in a web interface.
+#    This tools run scripts and display the result in a Web Interface.
 #    Copyright (C) 2021  Maurice Lambert
 
 #    This program is free software: you can redistribute it and/or modify
@@ -20,9 +19,7 @@
 #    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 ###################
 
-"""This package implements a web server to run scripts or 
-executables from the command line and display the result 
-in a web interface.
+"""This tools run scripts and display the result in a Web Interface.
 
 This file is the "main" file of this package (implement the main function,
 the Server class and the Configuration class)."""
@@ -33,6 +30,7 @@ from argparse import Namespace, ArgumentParser
 from typing import TypeVar, Tuple, List, Dict
 from os import path, _Environ, getcwd, mkdir
 from wsgiref import simple_server
+from threading import Thread
 from base64 import b64decode
 from glob import iglob
 import traceback
@@ -42,6 +40,7 @@ import json
 import sys
 
 if __package__:
+    from .hardening import main as hardening
     from .Pages import (
         Pages,
         Argument,
@@ -62,6 +61,7 @@ if __package__:
         WebScriptsConfigurationTypeError,
     )
 else:
+    from hardening import main as hardening
     from Pages import (
         Pages,
         Argument,
@@ -82,13 +82,12 @@ else:
         WebScriptsConfigurationTypeError,
     )
 
-__version__ = "0.0.7"
+__version__ = "0.0.9"
 __author__ = "Maurice Lambert"
 __author_email__ = "mauricelambert434@gmail.com"
 __maintainer__ = "Maurice Lambert"
 __maintainer_email__ = "mauricelambert434@gmail.com"
-__description__ = """This package implements a web server to run scripts or 
-executables from the command line and display the result in a web interface.
+__description__ = """This tools run scripts and display the result in a Web Interface.
 
 This file is the "main" file of this package (implement the main function,
 the Server class and the Configuration class)."""
@@ -108,6 +107,7 @@ __all__ = ["Configuration", "Server", "main"]
 
 NameSpace = TypeVar("NameSpace", SimpleNamespace, Namespace)
 FunctionOrNone = TypeVar("FunctionOrNone", FunctionType, None)
+Content = TypeVar("Content", List[Dict[str, JsonValue]], Dict[str, JsonValue], bytes)
 
 
 class Configuration(DefaultNamespace):
@@ -124,6 +124,8 @@ class Configuration(DefaultNamespace):
         "statics_path": [],
         "scripts_path": [],
         "modules_path": [],
+        "exclude_auth_paths": ["/static/", "/js/"],
+        "exclude_auth_pages": ["/api/", "/auth/", "/web/auth/"],
         "auth_script": None,
         "active_auth": False,
         "documentations_path": [],
@@ -138,6 +140,8 @@ class Configuration(DefaultNamespace):
         "auth_script",
         "accept_unknow_user",
         "accept_unauthenticated_user",
+        "exclude_auth_paths",
+        "exclude_auth_pages",
         "modules",
         "modules_path",
         "js_path",
@@ -258,15 +262,28 @@ class Server:
             self.headers["Cache-Control"] = "no-store"
             self.headers["Pragma"] = "no-store"
             self.headers["Clear-Site-Data"] = "*"
-            self.headers["Feature-Policy"] = "microphone 'none'; camera 'none'"
+            self.headers[
+                "Feature-Policy"
+            ] = "payment 'none'; geolocation 'none'; microphone 'none'; camera 'none'"
+            self.headers[
+                "Permissions-Policy"
+            ] = "microphone=(),camera=(),payment=(),geolocation=()"
             self.headers["Cross-Origin-Embedder-Policy"] = "require-corp"
             self.headers["Cross-Origin-Opener-Policy"] = "same-origin"
             self.headers["Cross-Origin-Resource-Policy"] = "same-origin"
             self.headers["X-Server"] = "WebScripts"
         else:
-            self.headers[
-                "Content-Security-Policy-Report-Only"
-            ] = "default-src 'self'; form-action 'none'; frame-ancestors 'none'"
+            if "csp" not in configuration.modules:
+                configuration.modules.append("csp")
+            if "modules" not in configuration.modules_path:
+                configuration.modules_path.append("modules")
+            if "/csp/debug/" not in configuration.exclude_auth_pages:
+                configuration.exclude_auth_pages.append("/csp/debug/")
+
+            self.headers["Content-Security-Policy-Report-Only"] = (
+                "default-src 'self'; form-action 'none'; frame-ancestors 'none'"
+                "; report-uri /csp/debug/"
+            )
 
         self.add_module_or_package()
         self.add_paths()
@@ -433,24 +450,28 @@ class Server:
             )
 
     @log_trace
-    def get_function_page(self, path: str) -> FunctionOrNone:
+    def get_function_page(self, path: str) -> Tuple[FunctionOrNone, str, bool]:
 
-        """This function find function from URL path."""
+        """This function find function from URL path.
+        If the function is a WebScripts built-in function,
+        return the function, filename and True. Else return the
+        function, filename and False."""
 
         path = path.split("/")
         del path[0]
 
-        default, filename = self.get_attributes(self.pages, path)
+        default, filename, _ = self.get_attributes(self.pages, path)
 
         if default is not None:
-            return default, filename
+            return default, filename, True
         else:
-            return self.get_attributes(self.pages.packages, path)
+            return self.get_attributes(self.pages.packages, path, False)
 
     @log_trace
     def get_URLs(self) -> List[str]:
 
-        """This function return a list of string."""
+        """This function return a list of urls (scripts, documentation...)
+        and the start of the URL of custom packages."""
 
         urls = ["/api/", "/web/"]
 
@@ -477,8 +498,8 @@ class Server:
 
     @log_trace
     def get_attributes(
-        self, object_: object, attributes: List[str]
-    ) -> Tuple[FunctionOrNone, str]:
+        self, object_: object, attributes: List[str], is_not_package: bool = True
+    ) -> Tuple[FunctionOrNone, str, bool]:
 
         """This function get recursive attribute from object."""
 
@@ -487,12 +508,12 @@ class Server:
             object_ = getattr(object_, attribute, None)
 
             if object_ is None:
-                return None, None
+                return None, None, is_not_package
 
         if isinstance(object_, Callable):
-            return object_, attributes[-1]
+            return object_, attributes[-1], is_not_package
         else:
-            return None, None
+            return None, None, is_not_package
 
     @log_trace
     def get_inputs(
@@ -517,7 +538,7 @@ class Server:
         return inputs, arguments
 
     @log_trace
-    def parse_body(self, environ: _Environ) -> Tuple[List[Dict[str, JsonValue]], str]:
+    def parse_body(self, environ: _Environ) -> Tuple[Content, str, bool]:
 
         """This function return arguments from body."""
 
@@ -531,15 +552,31 @@ class Server:
         body = environ["wsgi.input"].read(content_length)
 
         if content_length:
-            body = json.loads(body)
+            try:
+                body = json.loads(body)
+            except json.decoder.JSONDecodeError:
+                Logs.warning("Non-JSON content detected")
+                Logs.info(
+                    "This request is not available for"
+                    " the default functions of WebScripts"
+                )
+                return body, None, False
 
-            arguments = []
-            for name, argument in body["arguments"].items():
-                arguments += Argument.get_command(name, argument)
+            if "arguments" in body.keys():
+                arguments = []
+                for name, argument in body["arguments"].items():
+                    arguments += Argument.get_command(name, argument)
 
-            return arguments, body.get("csrf_token")
+                return arguments, body.get("csrf_token"), True
 
-        return [], None
+            Logs.warning('Section "arguments" is not defined in the JSON content.')
+            Logs.info(
+                "This request is not available for"
+                " the default functions of WebScripts"
+            )
+            return body, None, False
+
+        return [], None, True
 
     @log_trace
     def app(self, environ: _Environ, respond: FunctionType) -> List[bytes]:
@@ -552,7 +589,9 @@ class Server:
             f"Request ({environ['REQUEST_METHOD']}) from {get_ip(environ)} on {environ['PATH_INFO']}."
         )
 
-        get_response, filename = self.get_function_page(environ["PATH_INFO"])
+        get_response, filename, is_not_package = self.get_function_page(
+            environ["PATH_INFO"]
+        )
 
         user, not_blacklisted = self.check_auth(environ)
 
@@ -562,9 +601,18 @@ class Server:
             )
             return self.page_403(None, respond)
 
-        arguments, csrf_token = self.parse_body(environ)
-        inputs, arguments = self.get_inputs(arguments)
-        error: str = None
+        arguments, csrf_token, is_webscripts_request = self.parse_body(environ)
+
+        if is_webscripts_request:
+            inputs, arguments = self.get_inputs(arguments)
+        else:
+            inputs = []
+
+        if is_not_package and not is_webscripts_request:
+            Logs.error(f'HTTP 406: for "{user.name}" on "{environ["PATH_INFO"]}"')
+            error = "406"
+        else:
+            error: str = None
 
         if (
             (
@@ -573,11 +621,11 @@ class Server:
             )
             and self.configuration.active_auth
         ) and (
-            environ["PATH_INFO"] != "/auth/"
-            and environ["PATH_INFO"] != "/web/auth/"
-            and environ["PATH_INFO"] != "/api/"
-            and not environ["PATH_INFO"].startswith("/js/")
-            and not environ["PATH_INFO"].startswith("/static/")
+            environ["PATH_INFO"] not in self.configuration.exclude_auth_pages
+            and not any(
+                environ["PATH_INFO"].startswith(x)
+                for x in self.configuration.exclude_auth_paths
+            )
         ):
             self.send_headers(respond, "302 Found", {"Location": "/web/auth/"})
             return [
@@ -590,6 +638,9 @@ class Server:
         if get_response is None:
             return self.page_404(environ["PATH_INFO"], respond)
 
+        if error == "406":
+            return self.page_406(None, respond)
+
         try:
             error, headers, page = get_response(
                 environ,
@@ -680,6 +731,15 @@ class Server:
         error = b"Forbidden (You don't have permissions)"
         return self.send_error_page(error_code, error, respond)
 
+    @log_trace
+    def page_406(self, error_description: str, respond: FunctionType):
+
+        """This function return error 406 web page."""
+
+        error_code = "406 Not Acceptable"
+        error = b"Not Acceptable, your request is not a valid WebScripts request."
+        return self.send_error_page(error_code, error, respond)
+
     @log_trace
     def send_error_page(
         self, error: str, data: bytes, respond: FunctionType
@@ -786,31 +846,62 @@ def parse_args() -> Namespace:
     dev.add_argument(
         "-s",
         "--security",
-        help="Remove HTTP security headers [Disable security].",
+        help="Remove HTTP security headers [Disable security],"
+        " active the Content-Security-Policy-Report-Only header"
+        ' and the CSP debug module (URL: "/csp/debug/")',
         action="store_false",
         default=None,
     )
 
-    parser.add_argument(
+    auth = parser.add_argument_group("AUTH", "authentication configurations")
+    auth.add_argument(
         "-a",
         "--active-auth",
         help="Disable authentication page [Disable auth (force to accept unknow and unauthenticated user)].",
         action="store_false",
         default=None,
     )
-    parser.add_argument("--auth-script", help="Script for authentication.")
-    parser.add_argument(
+    auth.add_argument("--auth-script", help="Script for authentication.")
+    auth.add_argument(
         "--accept-unauthenticated-user",
         help="Accept unauthenticated user.",
         action="store_true",
         default=None,
     )
-    parser.add_argument(
+    auth.add_argument(
         "--accept-unknow-user",
         help="Accept unknow user.",
         action="store_true",
         default=None,
     )
+    auth.add_argument(
+        "-b",
+        "--auth-failures-to-blacklist",
+        type=int,
+        help="Number of authentication failures to blacklist an IP or user.",
+    )
+    auth.add_argument(
+        "-B",
+        "--blacklist-time",
+        type=int,
+        help="Time (in seconds) to blacklist an IP or user.",
+    )
+    auth.add_argument(
+        "--e-auth-paths",
+        "--exclude-auth-paths",
+        action="extend",
+        nargs="+",
+        default=[],
+        help="Start of paths where the unauthenticated user gets access.",
+    )
+    auth.add_argument(
+        "--e-auth-pages",
+        "--exclude-auth-pages",
+        action="extend",
+        nargs="+",
+        default=[],
+        help="Specific page where the unauthenticated user has access.",
+    )
 
     parser.add_argument(
         "-S",
@@ -881,19 +972,6 @@ def parse_args() -> Namespace:
     logs.add_argument("--log-date-format", help="Date format for ROOT logger.")
     logs.add_argument("--log-encoding", help="Encoding for ROOT logger.")
 
-    parser.add_argument(
-        "-b",
-        "--auth-failures-to-blacklist",
-        type=int,
-        help="Number of authentication failures to blacklist an IP or user.",
-    )
-    parser.add_argument(
-        "-B",
-        "--blacklist-time",
-        type=int,
-        help="Time (in seconds) to blacklist an IP or user.",
-    )
-
     smtp = parser.add_argument_group(
         "SMTP", "SMTP configurations to send email notifications"
     )
@@ -1097,7 +1175,13 @@ def send_mail(configuration: Configuration, message: str) -> int:
 
     error_pages = getattr(Pages.packages, "error_pages", None)
     if error_pages:
-        error_pages.Request.send_mail(configuration, message)
+        Thread(
+            target=error_pages.Request.send_mail,
+            args=(
+                configuration,
+                message,
+            ),
+        ).start()
         return 0
 
     return 1
@@ -1141,6 +1225,8 @@ def main() -> None:
     send_mail(
         configuration, f"Server is up on http://{server.interface}:{server.port}/."
     )
+    hardening(server, Logs)
+
     try:
         httpd.serve_forever()
     except KeyboardInterrupt:
