@@ -19,9 +19,7 @@
 #    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 ###################
 
-"""This package implements a web server to run scripts or 
-executables from the command line and display the result 
-in a web interface.
+"""This tools run scripts and display the result in a Web Interface.
 
 This file can decrypt and print a secure password share."""
 
@@ -30,8 +28,8 @@ __author__ = "Maurice Lambert"
 __author_email__ = "mauricelambert434@gmail.com"
 __maintainer__ = "Maurice Lambert"
 __maintainer_email__ = "mauricelambert434@gmail.com"
-__description__ = """This package implements a web server to run scripts or 
-executables from the command line and display the result in a web interface.
+__description__ = """
+This tools run scripts and display the result in a Web Interface.
 
 This file can decrypt and print a secure password share."""
 __license__ = "GPL-3.0 License"
@@ -49,6 +47,7 @@ __copyright__ = copyright
 __all__ = ["save", "delete", "decrypt", "get_passwords", "main"]
 
 from typing import TypeVar, Tuple, List
+from hmac import compare_digest
 from hashlib import pbkdf2_hmac
 from csv import reader, writer
 from base64 import b64decode
@@ -73,7 +72,9 @@ def decrypt(key: bytes, password: bytes, hash_: str, iteration: int) -> Password
     for i, car in enumerate(password):
         password_ += chr(key[i % key_length] ^ car)
 
-    if pbkdf2_hmac("sha512", password_.encode(), key, int(iteration)).hex() == hash_:
+    if compare_digest(
+        pbkdf2_hmac("sha512", password_.encode(), key, int(iteration)).hex(), hash_
+    ):
         return password_
     else:
         return False
