@@ -2,8 +2,7 @@
 # -*- coding: utf-8 -*-
 
 ###################
-#    This package implements a web server to run scripts or executables
-#    from the command line and display the result in a web interface.
+#    This tools run scripts and display the result in a Web Interface.
 #    Copyright (C) 2021  Maurice Lambert
 
 #    This program is free software: you can redistribute it and/or modify
@@ -20,9 +19,7 @@
 #    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 ###################
 
-"""This package implements a web server to run scripts or 
-executables from the command line and display the result 
-in a web interface.
+"""This tools run scripts and display the result in a Web Interface.
 
 This file implement some tools for WebScripts server
 and scripts (Logs, Namespace for configuration, ...)."""
@@ -58,13 +55,12 @@ else:
         WebScriptsSecurityError,
     )
 
-__version__ = "0.0.6"
+__version__ = "0.0.7"
 __author__ = "Maurice Lambert"
 __author_email__ = "mauricelambert434@gmail.com"
 __maintainer__ = "Maurice Lambert"
 __maintainer_email__ = "mauricelambert434@gmail.com"
-__description__ = """This package implements a web server to run scripts or 
-executables from the command line and display the result in a web interface.
+__description__ = """This tools run scripts and display the result in a Web Interface.
 
 This file implement some tools for WebScripts server
 and scripts (Logs, Namespace for configuration, ...)."""
@@ -311,14 +307,14 @@ def log_trace(function: FunctionType):
 
     @wraps(function)
     def wrapper(*args, **kwds):
-        if isinstance(function, classmethod) or isinstance(function, staticmethod):
-            name = function.__func__.__name__
-        else:
-            name = function.__name__
+        # if isinstance(function, classmethod) or isinstance(function, staticmethod):
+        #    name = function.__func__.__name__
+        # else:
+        #    name = function.__name__
 
-        Logs.trace(f"Start {name}...")
+        Logs.trace(f"Start {function.__name__}...")
         values = function(*args, **kwds)
-        Logs.trace(f"End of {name}.")
+        Logs.trace(f"End of {function.__name__}.")
         return values
 
     return wrapper
@@ -619,6 +615,8 @@ def get_file_content(file_path, *args, **kwargs) -> StrOrBytes:
                 content = file.read()
             return content
 
+    raise UnicodeDecodeError("No encoding found to open this file.")
+
 
 @log_trace
 def get_real_path(file_path: str) -> str:
